@@ -6,19 +6,23 @@ code to read the netcdf unstructured grid standard:
 https://github.com/ugrid-conventions/ugrid-conventions/
 
 This code is called by the UGrid class to load into a UGRID object.
-
-    NOTE: passing the UGrid object in to avoid circular references,
-    while keeping the netcdf reading code in its own file.
-
 """
 
+# NOTE: passing the UGrid object in to avoid circular references,
+# while keeping the netcdf reading code in its own file.
+
+
 from __future__ import (absolute_import, division, print_function)
 
+import logging
+
 import numpy as np
 import netCDF4
 
 from .uvar import UVar
 
+logger = logging.getLogger(__name__)
+
 
 def find_mesh_names(nc):
     """
@@ -47,15 +51,20 @@ def is_valid_mesh(nc, varname):
     try:
         mesh_var = nc.variables[varname]
     except KeyError:
+        logger.info('Key error %s', varname)
         return False
     try:
-        if (mesh_var.cf_role.strip() == 'mesh_topology' and
-           int(mesh_var.topology_dimension) == 2):
+        if (
+                mesh_var.cf_role.strip() == 'mesh_topology' and
+                int(mesh_var.topology_dimension) in {1, 2}
+        ):
             return True
     except AttributeError:
-            # not a valid mesh variable
+        logger.info('Attribute error %s', mesh_var)
+        # not a valid mesh variable
         return False
 
+
 # Defining properties of various connectivity arrays
 # so that the same code can load all of them.
 grid_defs = [{'grid_attr': 'faces',  # Name in UGrid object.
@@ -184,13 +193,15 @@ def load_grid_from_nc_dataset(nc, grid, mesh_name=None, load_data=True):
                     msg = ("{} variable's units value ({}) doesn't look "
                            "like latitude or longitude").format
                     raise ValueError(msg(var, units))
-            if standard_name == 'latitude':
+            if standard_name in {'latitude', 'projection_y_coordinate'}:
                 nodes[:, 1] = var[:]
-            elif standard_name == 'longitude':
+            elif standard_name in {'longitude', 'projection_x_coordinate'}:
                 nodes[:, 0] = var[:]
             else:
-                raise ValueError('Node coordinates standard_name is neither '
-                                 '"longitude" nor "latitude" ')
+                raise ValueError('Node coordinates standard_name is neither'
+                                 ' "longitude" nor "latitude" nor '
+                                 '"projection_x_coordinate" nor '
+                                 ' "projection_y_coordinate"')
         setattr(grid, defs['grid_attr'], nodes)
 
     # Load assorted connectivity arrays.
@@ -215,7 +226,7 @@ def load_grid_from_nc_dataset(nc, grid, mesh_name=None, load_data=True):
                 try:
                     # FIXME: This won't work for more than one flag value.
                     flag_value = var.flag_values
-                    array[array == flag_value-start_index] = flag_value
+                    array[array == flag_value - start_index] = flag_value
                 except AttributeError:
                     pass
             setattr(grid, defs['grid_attr'], array)
@@ -242,7 +253,8 @@ def load_grid_from_nc_dataset(nc, grid, mesh_name=None, load_data=True):
                           if n not in ('location', 'coordinates', 'mesh')}
 
             # Trick with the name: FIXME: Is this a good idea?
-            name = name.lstrip(mesh_name).lstrip('_')
+            if name.startswith(mesh_name+"_"):
+                name = name[len(mesh_name)+1:]
             uvar = UVar(name, data=var[:],
                         location=location, attributes=attributes)
             grid.add_data(uvar)
